@@ -18,13 +18,15 @@ import json
 from alex.alex import const, dsl_parser
 
 
-def get_input_components(component):
-    return component[const.META][const.INPUT_COMPONENT]
+def get_inputss(component):
+    return component[const.META][const.INPUTS]
 
 
 # FIXME: use typing
 def get_value_type(label):
-    if label in const.INGREDIENT_TYPES or label in const.INPUTS:
+    if label in const.INGREDIENT_TYPES \
+       or label in const.INPUT_TYPES \
+       or label in const.REGULARIZERS:
         node_type = "ingredient"
     elif label in const.ALL_RECIPES:
         node_type = "recipe"
@@ -85,24 +87,12 @@ def get_ancestor_param_node(node, tree, field=None):
         return parent_node[field]
 
 
-def get_ancestor_ingredient_node(node, components, tree, field=None):
-    tree = deepcopy(tree)
-    components = deepcopy(components)
-    node = deepcopy(node)
-    if node["name"] in components \
-       or node["name"] == "root" \
-       or node["type"] == "recipe":
-        parent_node = node
-    else:
-        parent = node["parent"]
-        while parent not in components:
-            _name = parent
-            parent = tree[_name]["parent"]
-        parent_node = tree[parent]
+def get_ancestor_ingredient_node(node, tree, field=None):
+    name = node["meta"]["position"]["component"]
     if field is None:
-        return parent_node
+        return tree[name]
     else:
-        return parent_node[field]
+        return tree[name][field]
 
 
 def get_parent(root, tree, field=None):
@@ -182,7 +172,7 @@ def alex_graph_to_json(graph,
                        json_obj=collections.OrderedDict(),
                        naive=True,
                        label_path=None,
-                       position: dict = {"input_component": None,
+                       position: dict = {"inputs": None,
                                          "component": None,
                                          "input_shape": None}):
     """
@@ -199,7 +189,7 @@ def alex_graph_to_json(graph,
     if isinstance(graph, dict) \
        and "subgraph" in graph \
        and isinstance(graph["subgraph"], dict): # is a recipe
-        _position = {"input_component": graph["input_component"],
+        _position = {"inputs": graph["inputs"],
                      "component": root_name,
                      "input_shape": None}
         label = deepcopy(graph["type"])
@@ -212,7 +202,7 @@ def alex_graph_to_json(graph,
         root_name = str(root_name)
         json_obj[root_name] = collections.OrderedDict()
         for _name, _graph in graph["subgraph"].items():
-            _position = {"input_component": _graph["input_component"],
+            _position = {"inputs": _graph["inputs"],
                          "component": _name,
                          "input_shape": None}
             _json_obj = alex_graph_to_json(_graph,
@@ -225,6 +215,7 @@ def alex_graph_to_json(graph,
     else: # if is an ingredient or hyperparameters
         if isinstance(graph, dict) and "hyperparams" in graph:
             if len(graph["hyperparams"]) != 0: # if is an ingredient with hyperparameter
+
                 if not naive:
                     hyperparam_str = str(uuid.uuid3(uuid.NAMESPACE_DNS,
                                                     json.dumps(graph["hyperparams"],
@@ -233,7 +224,7 @@ def alex_graph_to_json(graph,
                 else:
                     label = graph["type"]
 
-                _position = {"input_component": graph["input_component"],
+                _position = {"inputs": graph["inputs"],
                              "component": root_name,
                              "input_shape": None}
                 _root_name = root_name
@@ -242,7 +233,8 @@ def alex_graph_to_json(graph,
                              "name": root_name,
                              "meta": {"hyperparams": graph["hyperparams"],
                                       "position": _position,
-                                      "label_path": label_path}}
+                                      "label_path": label_path,
+                                      "block": graph["meta"]["block"]}}
                 root_name = str(root_name)
                 json_obj[root_name] = collections.OrderedDict()
                 for _name in sorted(graph["hyperparams"]):
@@ -261,7 +253,7 @@ def alex_graph_to_json(graph,
                     json_obj[root_name].update(_json_obj)
 
             else:
-                _position = {"input_component": graph["input_component"],
+                _position = {"inputs": graph["inputs"],
                              "component": root_name,
                              "input_shape": None}
 
@@ -270,7 +262,8 @@ def alex_graph_to_json(graph,
                              "name": root_name,
                              "meta": {"hyperparams": {},
                                       "position": _position,
-                                      "label_path": label_path}}
+                                      "label_path": label_path,
+                                      "block": graph["meta"]["block"]}}
                 root_name = str(root_name)
 
                 json_obj[root_name] = None
@@ -279,7 +272,6 @@ def alex_graph_to_json(graph,
             _root_name = deepcopy(root_name)
             _value = _root_name.split("/")[-1]
             label_path = "%s/%s" % (label_path, _value)
-
             root_name = {"value": _value,
                          "label": label_path,
                          "name":  _root_name,
@@ -424,7 +416,6 @@ def alex_graph_to_tree(network_graph, exclude_types=[], naive=True):
 
 
 def draw(tree, graph_path='example.png', annotation=dict(), dpi=800, size=5, label_field="value", excluded_types=[]):
-    # pprint(tree)
     graph = pydot.Dot(graph_type='digraph', rankdir='LR', dpi=dpi, size=size, fontsize=12)
     for component in tree:
         name = component
@@ -446,7 +437,6 @@ def draw(tree, graph_path='example.png', annotation=dict(), dpi=800, size=5, lab
                               fillcolor=color)
             graph.add_node(node)
         children_list = tree[component]["children"].copy()
-        # children_list.reverse()
         for child in children_list:
             if tree[child]["type"] in excluded_types:
                 continue
@@ -466,8 +456,14 @@ def draw(tree, graph_path='example.png', annotation=dict(), dpi=800, size=5, lab
                                   shape="box",
                                   style = 'filled',
                                   fillcolor=color)
-
+                # if isinstance(tree[child]["meta"], dict):
+                #     if tree[child]["name"] != "root" and "block" in tree[child]["meta"]:
+                #         block = tree[child]["meta"]["block"]
+                #         blocks[block].add_node(node)
+                #     else:
+                          # graph.add_node(node)
                 graph.add_node(node)
+
             edge = pydot.Edge(component, child)
             graph.add_edge(edge)
 
